@@ -1,7 +1,7 @@
 /*
  * This file is part of brisk-menu.
  *
- * Copyright © 2016-2017 Brisk Menu Developers
+ * Copyright © 2016-2019 Brisk Menu Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,15 @@ struct _BriskMenuEntryButtonClass {
         void (*show_context_menu)(BriskMenuEntryButton *button, BriskItem *item);
 };
 
+/**
+ * BriskMenuEntryButton is the toplevel window type used within the applet.
+ */
+struct _BriskMenuEntryButton {
+        GtkButton parent;
+        BriskMenuLauncher *launcher;
+        BriskItem *item;
+};
+
 #define BRISK_TYPE_MENU_ENTRY_BUTTON brisk_menu_entry_button_get_type()
 #define BRISK_MENU_ENTRY_BUTTON(o)                                                                 \
         (G_TYPE_CHECK_INSTANCE_CAST((o), BRISK_TYPE_MENU_ENTRY_BUTTON, BriskMenuEntryButton))
@@ -39,11 +48,6 @@ struct _BriskMenuEntryButtonClass {
 #define BRISK_MENU_ENTRY_BUTTON_GET_CLASS(o)                                                       \
         (G_TYPE_INSTANCE_GET_CLASS((o), BRISK_TYPE_MENU_ENTRY_BUTTON, BriskMenuEntryButtonClass))
 
-/**
- * Construct a new BriskMenuEntryButton from the given entry
- */
-GtkWidget *brisk_menu_entry_button_new(BriskMenuLauncher *launcher, BriskItem *item);
-
 void brisk_menu_entry_button_launch(BriskMenuEntryButton *button);
 
 GType brisk_menu_entry_button_get_type(void);
