@@ -1,7 +1,7 @@
 /*
  * This file is part of brisk-menu.
  *
- * Copyright © 2016-2017 Brisk Menu Developers
+ * Copyright © 2016-2019 Brisk Menu Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,7 +12,6 @@
 #include "util.h"
 
 BRISK_BEGIN_PEDANTIC
-#include "entry-button.h"
 #include "menu-private.h"
 BRISK_END_PEDANTIC
 
@@ -24,12 +23,17 @@ gboolean brisk_menu_window_key_press(BriskMenuWindow *self, GdkEvent *event,
                                      __brisk_unused__ gpointer v)
 {
         autofree(gchar) *accel_name = NULL;
+        GdkModifierType lock_masks = GDK_MOD2_MASK | GDK_LOCK_MASK | GDK_MOD5_MASK;
+        guint mods;
 
         if (!self->shortcut) {
                 return GDK_EVENT_PROPAGATE;
         }
 
-        accel_name = gtk_accelerator_name(event->key.keyval, event->key.state);
+        /* Unset mask of the lock keys */
+        mods = event->key.state & ~(lock_masks);
+
+        accel_name = gtk_accelerator_name(event->key.keyval, mods);
         if (!accel_name || g_ascii_strcasecmp(self->shortcut, accel_name) != 0) {
                 return GDK_EVENT_PROPAGATE;
         }
@@ -51,30 +55,6 @@ gboolean brisk_menu_window_key_release(BriskMenuWindow *self, GdkEvent *event,
         return GDK_EVENT_PROPAGATE;
 }
 
-void brisk_menu_window_key_activate(BriskMenuWindow *self, __brisk_unused__ gpointer v)
-{
-        autofree(GList) *kids = NULL;
-        GList *elem = NULL;
-        BriskMenuEntryButton *button = NULL;
-
-        kids = gtk_container_get_children(GTK_CONTAINER(self->apps));
-
-        for (elem = kids; elem; elem = elem->next) {
-                GtkWidget *widget = elem->data;
-
-                if (!gtk_widget_get_visible(widget) || !gtk_widget_get_child_visible(widget)) {
-                        continue;
-                }
-
-                button = BRISK_MENU_ENTRY_BUTTON(gtk_bin_get_child(GTK_BIN(widget)));
-                break;
-        }
-        if (!button) {
-                return;
-        }
-        brisk_menu_entry_button_launch(button);
-}
-
 /**
  * Called in idle once back out of the event
  */
