@@ -1,7 +1,7 @@
 /*
  * This file is part of brisk-menu.
  *
- * Copyright © 2016-2017 Brisk Menu Developers
+ * Copyright © 2016-2019 Brisk Menu Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,119 +31,115 @@ typedef enum {
 
 struct _BriskMenuWindowClass {
         GtkWindowClass parent_class;
+
+        const gchar *(*get_id)(BriskMenuWindow *);
+        const gchar *(*get_display_name)(BriskMenuWindow *);
+        void (*update_screen_position)(BriskMenuWindow *);
+        void (*update_search)(BriskMenuWindow *);
+        void (*add_item)(BriskMenuWindow *, BriskItem *, BriskBackend *);
+        void (*add_section)(BriskMenuWindow *, BriskSection *, BriskBackend *);
+        void (*invalidate_filter)(BriskMenuWindow *, BriskBackend *);
+        void (*reset)(BriskMenuWindow *, BriskBackend *);
+
+        gpointer padding[12];
 };
 
 /**
- * BriskMenuWindow is the toplevel window type used within the applet.
+ * BriskMenuWindow is an abstract top-level class which is used as the base
+ * of all other window implementations within Brisk.
  */
 struct _BriskMenuWindow {
         GtkWindow parent;
+        /* Current panel position */
+        GtkPositionType position;
 
-        /* Who "owns" us */
-        GtkWidget *relative_to;
-
-        /* Control launches */
-        BriskMenuLauncher *launcher;
-
-        /* Control hotkeys */
-        BriskKeyBinder *binder;
-        gchar *shortcut;
-
-        /* Categories */
-        GtkWidget *sidebar;
-        GtkWidget *sidebar_scroll;
-
-        /* Each backend gets its own box in the sidebar */
-        GHashTable *section_boxes;
-        /* Each backend is also plugged into one big map */
-        GHashTable *backends;
-
-        /* VBox for the sidebar container */
-        GtkWidget *sidebar_wrap;
-        GtkWidget *sidebar_leader;
+        /* Current search position */
+        SearchPosition search_position;
 
         /* Top search entry */
         GtkWidget *search;
 
-        /* Actual applications */
-        GtkWidget *apps;
-        GtkWidget *apps_scroll;
-
-        /* The current section used in filtering */
-        BriskSection *active_section;
-
-        /* Search term, may be null at any point. Used for filtering */
-        gchar *search_term;
-
-        /* Our CSS assets */
-        GtkCssProvider *css;
-
-        gboolean filtering;
-
         /* Whether we have a grab or not */
         gboolean grabbed;
 
         /* Whether we're in rollover mode or not */
         gboolean rollover;
 
-        /* Session management */
-        GnomeSessionManager *session;
-        MateScreenSaver *saver;
-        GtkWidget *button_lock;
-        GtkWidget *button_logout;
-        GtkWidget *button_shutdown;
-
         /* Global settings for all BriskMenu instances */
         GSettings *settings;
 
+        /* Control hotkeys */
+        BriskKeyBinder *binder;
+        gchar *shortcut;
+
+        GtkWidget *context_menu;
+        GActionGroup *context_group;
+
+        /* Each backend gets its own box in the sidebar */
+        GHashTable *section_boxes;
+
+        /* Each backend is also plugged into one big map */
+        GHashTable *backends;
+
         /* Acknowledge a single ID "contains" map */
         GHashTable *item_store;
 
-        /* Right-click on entry items */
-        GtkWidget *context_menu;
-        GActionGroup *context_group;
+        /* Control launches */
+        BriskMenuLauncher *launcher;
 
-        /* Current panel position */
-        GtkPositionType position;
+        /* Search term, may be null at any point. Used for filtering */
+        gchar *search_term;
 
-        /* Current search position */
-        SearchPosition search_position;
+        /* The current section used in filtering */
+        BriskSection *active_section;
+
+        gboolean filtering;
+
+        GtkWidget *relative_to;
+
+        /* The widget that contains our backend section boxes */
+        GtkWidget *section_box_holder;
+
+        GtkWidget *section_box_leader;
+
+        /* Session management */
+        GnomeSessionManager *session;
+        MateScreenSaver *saver;
 };
 
-/* Split the implementation across multiple files for ease of maintenance */
+GtkWidget *brisk_menu_window_get_section_box(BriskMenuWindow *self, BriskBackend *backend);
+
+/**
+ * Update internal notion of where the parent panel is on screen
+ */
+void brisk_menu_window_set_parent_position(BriskMenuWindow *window, GtkPositionType position);
+void brisk_menu_window_select_sections(BriskMenuWindow *self);
+GtkWidget *brisk_menu_window_find_first_visible_radio(BriskMenuWindow *self);
+
+/* Loader */
 gboolean brisk_menu_window_load_menus(BriskMenuWindow *self);
 void brisk_menu_window_init_backends(BriskMenuWindow *self);
-void brisk_menu_window_associate_category(BriskMenuWindow *self, GtkWidget *button);
-void brisk_menu_window_select_sidebar(BriskMenuWindow *self);
-
-/* Search */
-void brisk_menu_window_search(BriskMenuWindow *self, GtkEntry *entry);
-gboolean brisk_menu_window_filter_apps(GtkListBoxRow *row, gpointer v);
-void brisk_menu_window_activated(BriskMenuWindow *self, GtkListBoxRow *row, gpointer v);
-void brisk_menu_window_clear_search(GtkEntry *entry, GtkEntryIconPosition pos, GdkEvent *event,
-                                    gpointer v);
+void brisk_menu_window_remove_category(GtkWidget *widget, BriskMenuWindow *self);
 
 /* Sorting */
-gint brisk_menu_window_sort(GtkListBoxRow *row1, GtkListBoxRow *row2, gpointer v);
+gint brisk_menu_window_sort(BriskMenuWindow *self, BriskItem *itemA, BriskItem *itemB);
 
 /* Keyboard */
 gboolean brisk_menu_window_key_press(BriskMenuWindow *self, GdkEvent *event, gpointer v);
 gboolean brisk_menu_window_key_release(BriskMenuWindow *self, GdkEvent *event, gpointer v);
 void brisk_menu_window_update_hotkey(BriskMenuWindow *self, gchar *key);
-void brisk_menu_window_key_activate(BriskMenuWindow *self, gpointer v);
-
-void brisk_menu_window_set_filters_enabled(BriskMenuWindow *self, gboolean enabled);
 
 /* Global grabs */
 void brisk_menu_window_configure_grabs(BriskMenuWindow *self);
 
 /* Session controls */
-void brisk_menu_window_setup_session_controls(BriskMenuWindow *self);
+void brisk_menu_window_logout(BriskMenuWindow *self, gpointer v);
+void brisk_menu_window_shutdown(BriskMenuWindow *self, gpointer v);
+void brisk_menu_window_lock(BriskMenuWindow *self, gpointer v);
 gboolean brisk_menu_window_setup_session(BriskMenuWindow *self);
 
 /* Settings */
 void brisk_menu_window_init_settings(BriskMenuWindow *self);
-void brisk_menu_window_update_search(BriskMenuWindow *self);
 void brisk_menu_window_pump_settings(BriskMenuWindow *self);
 
 /* Context menu */
@@ -151,6 +147,12 @@ void brisk_menu_window_show_context(BriskMenuWindow *self, BriskItem *item,
                                     BriskMenuEntryButton *button);
 void brisk_menu_window_configure_context(BriskMenuWindow *self);
 
+/* Search */
+void brisk_menu_window_clear_search(GtkEntry *entry, GtkEntryIconPosition pos, GdkEvent *event,
+                                    gpointer v);
+void brisk_menu_window_search(BriskMenuWindow *self, GtkEntry *entry);
+gboolean brisk_menu_window_filter_apps(BriskMenuWindow *self, GtkWidget *child);
+
 DEF_AUTOFREE(GtkWidget, gtk_widget_destroy)
 DEF_AUTOFREE(GSList, g_slist_free)
 DEF_AUTOFREE(GList, g_list_free)
