@@ -1,7 +1,7 @@
 /*
  * This file is part of brisk-menu.
  *
- * Copyright © 2016-2017 Brisk Menu Developers
+ * Copyright © 2016-2019 Brisk Menu Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,6 +34,11 @@
  */
 #define BRISK_STYLE_BUTTON_VERTICAL "brisk-button-vertical"
 
+/**
+ * This is a dash window
+ */
+#define BRISK_STYLE_DASH "brisk-dash"
+
 /*
  * Editor modelines  -  https://www.wireshark.org/tools/modelines.html
  *
